@@ -14,6 +14,8 @@ pub mod basic_auth_options;
 pub use self::basic_auth_options::BasicAuthOptions;
 pub mod bulk_send_email_options;
 pub use self::bulk_send_email_options::BulkSendEmailOptions;
+pub mod condition_option;
+pub use self::condition_option::ConditionOption;
 pub mod contact_dto;
 pub use self::contact_dto::ContactDto;
 pub mod contact_projection;
